@@ -14,6 +14,7 @@ from tests.expectdata.load.load_capiq_cat_annual import LOAD_CAPIQ_CAT_A_INDEX_D
 
 if DEVELOPMENT_MODE:
     from tests.utils.gen.data_load import print_test_data_def, get_keys_for_inc_data_items, get_keys_for_bs_data_items
+
     inc_keys = get_keys_for_inc_data_items()
     bs_keys = get_keys_for_bs_data_items()
 
@@ -137,13 +138,13 @@ class TestLoadStockrowCAT(LoadTest):
             index=a_index
         ),
         tax_exp=pd.Series(
-            [270000000.0, 968000000.0, 1720000000.0, 2528000000.0, 1319000000.0, 692000000.0, 916000000.0, 192000000.0,
+            [-270000000.0, 968000000.0, 1720000000.0, 2528000000.0, 1319000000.0, 692000000.0, 916000000.0, 192000000.0,
              3339000000.0, 1698000000.0],
             index=a_index
         ),
         net_income=pd.Series(
             [895000000.0, 2700000000.0, 4928000000.0, 5681000000.0, 3789000000.0, 2452000000.0, 2512000000.0,
-             67000000.0, 754000000.0, 6147000000.0],
+             -67000000.0, 754000000.0, 6147000000.0],
             index=a_index
         ),
         cash=pd.Series(
@@ -396,10 +397,10 @@ class TestLoadStockrowCAT(LoadTest):
         ebit=pd.Series(
             [229000000.0, 566000000.0, 997000000.0, 1172000000.0, 1276000000.0, 1824000000.0, 1423000000.0,
              1727000000.0, 2070000000.0, 2388000000.0, 2681000000.0, 2581000000.0, 1026000000.0, 1246000000.0,
-             1467000000.0, 1372000000.0, 1488000000.0, 1450000000.0, 1538000000.0, 1509000000.0, 869000000.0,
-             1895000000.0, 1262000000.0, 904000000.0, 126000000.0, 492000000.0, 864000000.0, 505000000.0, 1231000000.0,
-             405000000.0, 1284000000.0, 1647000000.0, 1288000000.0, 2238000000.0, 2299000000.0, 2244000000.0,
-             1468000000.0, 2371000000.0, 2288000000.0, 2115000000.0],
+             1467000000.0, 1372000000.0, 1488000000.0, 1450000000.0, 1538000000.0, 1509000000.0, -869000000.0,
+             1895000000.0, 1262000000.0, 904000000.0, -126000000.0, 492000000.0, 864000000.0, 505000000.0,
+             -1231000000.0, 405000000.0, 1284000000.0, 1647000000.0, 1288000000.0, 2238000000.0, 2299000000.0,
+             2244000000.0, 1468000000.0, 2371000000.0, 2288000000.0, 2115000000.0],
             index=q_index
         ),
         int_exp=pd.Series(
@@ -428,26 +429,26 @@ class TestLoadStockrowCAT(LoadTest):
         ebt=pd.Series(
             [141000000.0, 464000000.0, 916000000.0, 1087000000.0, 1201000000.0, 1737000000.0, 1333000000.0,
              1615000000.0, 1963000000.0, 2275000000.0, 2571000000.0, 2452000000.0, 911000000.0, 1126000000.0,
-             1347000000.0, 1256000000.0, 1379000000.0, 1340000000.0, 1418000000.0, 1381000000.0, 995000000.0,
-             1766000000.0, 1137000000.0, 777000000.0, 252000000.0, 363000000.0, 734000000.0, 379000000.0, 1351000000.0,
-             282000000.0, 1163000000.0, 1529000000.0, 1119000000.0, 2137000000.0, 2197000000.0, 2142000000.0,
-             1369000000.0, 2268000000.0, 2185000000.0, 2012000000.0],
+             1347000000.0, 1256000000.0, 1379000000.0, 1340000000.0, 1418000000.0, 1381000000.0, -995000000.0,
+             1766000000.0, 1137000000.0, 777000000.0, -252000000.0, 363000000.0, 734000000.0, 379000000.0,
+             -1351000000.0, 282000000.0, 1163000000.0, 1529000000.0, 1119000000.0, 2137000000.0, 2197000000.0,
+             2142000000.0, 1369000000.0, 2268000000.0, 2185000000.0, 2012000000.0],
             index=q_index
         ),
         tax_exp=pd.Series(
-            [91000000.0, 231000000.0, 209000000.0, 295000000.0, 233000000.0, 512000000.0, 318000000.0, 474000000.0,
+            [-91000000.0, 231000000.0, 209000000.0, 295000000.0, 233000000.0, 512000000.0, 318000000.0, 474000000.0,
              416000000.0, 689000000.0, 872000000.0, 753000000.0, 214000000.0, 246000000.0, 387000000.0, 310000000.0,
-             376000000.0, 418000000.0, 419000000.0, 364000000.0, 509000000.0, 521000000.0, 335000000.0, 218000000.0,
-             158000000.0, 92000000.0, 184000000.0, 96000000.0, 180000000.0, 90000000.0, 361000000.0, 470000000.0,
+             376000000.0, 418000000.0, 419000000.0, 364000000.0, -509000000.0, 521000000.0, 335000000.0, 218000000.0,
+             -158000000.0, 92000000.0, 184000000.0, 96000000.0, -180000000.0, 90000000.0, 361000000.0, 470000000.0,
              2418000000.0, 472000000.0, 490000000.0, 415000000.0, 321000000.0, 387000000.0, 565000000.0, 518000000.0],
             index=q_index
         ),
         net_income=pd.Series(
             [232000000.0, 233000000.0, 707000000.0, 792000000.0, 968000000.0, 1225000000.0, 1015000000.0, 1141000000.0,
              1547000000.0, 1586000000.0, 1699000000.0, 1699000000.0, 697000000.0, 880000000.0, 960000000.0, 946000000.0,
-             1003000000.0, 922000000.0, 999000000.0, 1017000000.0, 486000000.0, 1245000000.0, 802000000.0, 559000000.0,
-             94000000.0, 271000000.0, 550000000.0, 283000000.0, 1171000000.0, 192000000.0, 802000000.0, 1059000000.0,
-             1299000000.0, 1665000000.0, 1707000000.0, 1727000000.0, 1048000000.0, 1881000000.0, 1620000000.0,
+             1003000000.0, 922000000.0, 999000000.0, 1017000000.0, -486000000.0, 1245000000.0, 802000000.0, 559000000.0,
+             -94000000.0, 271000000.0, 550000000.0, 283000000.0, -1171000000.0, 192000000.0, 802000000.0, 1059000000.0,
+             -1299000000.0, 1665000000.0, 1707000000.0, 1727000000.0, 1048000000.0, 1881000000.0, 1620000000.0,
              1494000000.0],
             index=q_index
         ),
@@ -759,7 +760,7 @@ class TestLoadStockrowMAR(LoadTest):
             index=a_index
         ),
         ebit=pd.Series(
-            [152000000.0, 695000000.0, 526000000.0, 940000000.0, 988000000.0, 1159000000.0, 1350000000.0, 1424000000.0,
+            [-152000000.0, 695000000.0, 526000000.0, 940000000.0, 988000000.0, 1159000000.0, 1350000000.0, 1424000000.0,
              2504000000.0, 2366000000.0],
             index=a_index
         ),
@@ -780,17 +781,17 @@ class TestLoadStockrowMAR(LoadTest):
             index=a_index
         ),
         ebt=pd.Series(
-            [418000000.0, 551000000.0, 356000000.0, 849000000.0, 897000000.0, 1088000000.0, 1255000000.0, 1239000000.0,
+            [-418000000.0, 551000000.0, 356000000.0, 849000000.0, 897000000.0, 1088000000.0, 1255000000.0, 1239000000.0,
              2982000000.0, 2345000000.0],
             index=a_index
         ),
         tax_exp=pd.Series(
-            [65000000.0, 93000000.0, 158000000.0, 278000000.0, 271000000.0, 335000000.0, 396000000.0, 431000000.0,
+            [-65000000.0, 93000000.0, 158000000.0, 278000000.0, 271000000.0, 335000000.0, 396000000.0, 431000000.0,
              1523000000.0, 438000000.0],
             index=a_index
         ),
         net_income=pd.Series(
-            [353000000.0, 458000000.0, 198000000.0, 571000000.0, 626000000.0, 753000000.0, 859000000.0, 808000000.0,
+            [-353000000.0, 458000000.0, 198000000.0, 571000000.0, 626000000.0, 753000000.0, 859000000.0, 808000000.0,
              1459000000.0, 1907000000.0],
             index=a_index
         ),
@@ -1037,7 +1038,7 @@ class TestLoadStockrowMAR(LoadTest):
             index=q_index
         ),
         ebit=pd.Series(
-            [215000000.0, 180000000.0, 226000000.0, 167000000.0, 122000000.0, 191000000.0, 232000000.0, 144000000.0,
+            [215000000.0, 180000000.0, 226000000.0, 167000000.0, 122000000.0, 191000000.0, 232000000.0, -144000000.0,
              247000000.0, 175000000.0, 243000000.0, 213000000.0, 309000000.0, 226000000.0, 279000000.0, 245000000.0,
              238000000.0, 254000000.0, 316000000.0, 298000000.0, 291000000.0, 332000000.0, 369000000.0, 339000000.0,
              310000000.0, 367000000.0, 389000000.0, 171000000.0, 497000000.0, 546000000.0, 744000000.0, 790000000.0,
@@ -1065,7 +1066,7 @@ class TestLoadStockrowMAR(LoadTest):
             index=q_index
         ),
         ebt=pd.Series(
-            [174000000.0, 129000000.0, 184000000.0, 128000000.0, 110000000.0, 152000000.0, 201000000.0, 199000000.0,
+            [174000000.0, 129000000.0, 184000000.0, 128000000.0, 110000000.0, 152000000.0, 201000000.0, -199000000.0,
              202000000.0, 147000000.0, 209000000.0, 222000000.0, 271000000.0, 201000000.0, 263000000.0, 223000000.0,
              210000000.0, 231000000.0, 285000000.0, 290000000.0, 282000000.0, 307000000.0, 355000000.0, 309000000.0,
              284000000.0, 326000000.0, 344000000.0, 131000000.0, 438000000.0, 494000000.0, 716000000.0, 738000000.0,
@@ -1073,15 +1074,15 @@ class TestLoadStockrowMAR(LoadTest):
             index=q_index
         ),
         tax_exp=pd.Series(
-            [68000000.0, 46000000.0, 65000000.0, 45000000.0, 63000000.0, 51000000.0, 66000000.0, 20000000.0, 61000000.0,
-             43000000.0, 66000000.0, 79000000.0, 90000000.0, 65000000.0, 84000000.0, 63000000.0, 59000000.0, 59000000.0,
-             93000000.0, 98000000.0, 85000000.0, 100000000.0, 115000000.0, 99000000.0, 82000000.0, 107000000.0,
-             97000000.0, 61000000.0, 166000000.0, 123000000.0, 227000000.0, 253000000.0, 920000000.0, 112000000.0,
-             207000000.0, 91000000.0, 28000000.0, 57000000.0, 82000000.0, 140000000.0],
+            [68000000.0, 46000000.0, 65000000.0, 45000000.0, -63000000.0, 51000000.0, 66000000.0, -20000000.0,
+             61000000.0, 43000000.0, 66000000.0, 79000000.0, 90000000.0, 65000000.0, 84000000.0, 63000000.0, 59000000.0,
+             59000000.0, 93000000.0, 98000000.0, 85000000.0, 100000000.0, 115000000.0, 99000000.0, 82000000.0,
+             107000000.0, 97000000.0, 61000000.0, 166000000.0, 123000000.0, 227000000.0, 253000000.0, 920000000.0,
+             112000000.0, 207000000.0, 91000000.0, 28000000.0, 57000000.0, 82000000.0, 140000000.0],
             index=q_index
         ),
         net_income=pd.Series(
-            [106000000.0, 83000000.0, 119000000.0, 83000000.0, 47000000.0, 101000000.0, 135000000.0, 179000000.0,
+            [106000000.0, 83000000.0, 119000000.0, 83000000.0, 173000000.0, 101000000.0, 135000000.0, -179000000.0,
              141000000.0, 104000000.0, 143000000.0, 143000000.0, 181000000.0, 136000000.0, 179000000.0, 160000000.0,
              151000000.0, 172000000.0, 192000000.0, 192000000.0, 197000000.0, 207000000.0, 240000000.0, 210000000.0,
              202000000.0, 219000000.0, 247000000.0, 70000000.0, 272000000.0, 371000000.0, 489000000.0, 485000000.0,
@@ -1429,8 +1430,9 @@ class TestLoadCapitalIQ(LoadTest):
             index=q_inc_index
         ),
         ebit=pd.Series(
-            [2287, 2628, 2333, 1769, 1225, 1442, 1441, 1522, 1562, 1604, 1482, 1168, 1736, 1401, 1025, 496, 616, 908,
-             758, 397, 1063, 1308, 1587, 1589, 2225, 2335, 2301, 1732, 2296, 2295, 2063],
+            [2287.0, 2628.0, 2333.0, 1769.0, 1225.0, 1442.0, 1441.0, 1522.0, 1562.0, 1604.0, 1482.0, 1168.0, 1736.0,
+             1401.0, 1025.0, 496.0, 616.0, 908.0, 758.0, -397.0, 1063.0, 1308.0, 1587.0, 1589.0, 2225.0, 2335.0, 2301.0,
+             1732.0, 2296.0, 2295.0, 2063.0],
             index=q_inc_index
         ),
         int_exp=pd.Series(
@@ -1452,18 +1454,21 @@ class TestLoadCapitalIQ(LoadTest):
             index=q_inc_index
         ),
         ebt=pd.Series(
-            [2300, 2581, 2455, 914, 1128, 1352, 1260, 1382, 1343, 1421, 1385, 942, 1769, 1138, 780, 248, 364, 737, 379,
-             1347, 284, 1164, 1531, 1119, 2139, 2195, 2142, 1370, 2271, 2184, 2012],
+            [2300.0, 2581.0, 2455.0, 914.0, 1128.0, 1352.0, 1260.0, 1382.0, 1343.0, 1421.0, 1385.0, 942.0, 1769.0,
+             1138.0, 780.0, -248.0, 364.0, 737.0, 379.0, -1347.0, 284.0, 1164.0, 1531.0, 1119.0, 2139.0, 2195.0, 2142.0,
+             1370.0, 2271.0, 2184.0, 2012.0],
             index=q_inc_index
         ),
         tax_exp=pd.Series(
-            [689, 872, 753, 214, 246, 387, 310, 376, 418, 419, 364, 179, 521, 335, 218, 158, 92, 184, 96, 180, 90, 361,
-             470, 2418, 472, 490, 415, 321, 387, 565, 518],
+            [689.0, 872.0, 753.0, 214.0, 246.0, 387.0, 310.0, 376.0, 418.0, 419.0, 364.0, 179.0, 521.0, 335.0, 218.0,
+             -158.0, 92.0, 184.0, 96.0, -180.0, 90.0, 361.0, 470.0, 2418.0, 472.0, 490.0, 415.0, 321.0, 387.0, 565.0,
+             518.0],
             index=q_inc_index
         ),
         net_income=pd.Series(
-            [1586, 1699, 1699, 697, 880, 960, 946, 1003, 922, 999, 1017, 757, 1245, 802, 559, 94, 271, 550, 283, 1171,
-             192, 802, 1059, 1299, 1665, 1707, 1727, 1048, 1881, 1620, 1494],
+            [1586.0, 1699.0, 1699.0, 697.0, 880.0, 960.0, 946.0, 1003.0, 922.0, 999.0, 1017.0, 757.0, 1245.0, 802.0,
+             559.0, -94.0, 271.0, 550.0, 283.0, -1171.0, 192.0, 802.0, 1059.0, -1299.0, 1665.0, 1707.0, 1727.0, 1048.0,
+             1881.0, 1620.0, 1494.0],
             index=q_inc_index
         ),
     )
